==> custom_pages-v1.12.5.zip: custom_pages/messages/es/model.php <==
<?php

return [
    'Abstract' => 'Resumen',
    'Activate PHP based Pages and Snippets' => 'Activar páginas y fragmentos basados ​​en PHP',
    'Attach Files' => 'Adjuntar archivos',
    'Content' => 'Contenido',
    'Empty <br />Container' => 'Contenedor <br> vacío',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Si está deshabilitado, las páginas php existentes seguirán estando en línea, pero no se pueden crear.',
    'Label' => 'Etiqueta',
    'Open in new window' => 'Abrir en una nueva ventana',
    'PHP view path for custom space pages' => 'Ruta de vista PHP para páginas de espacio personalizadas',
    'PHP view path for custom space snippets' => 'Ruta de vista PHP para fragmentos de espacio personalizados',
    'PHP view path for global custom pages' => 'Ruta de vista PHP para páginas personalizadas globales',
    'PHP view path for global custom snippets' => 'Ruta de vista PHP para fragmentos personalizados globales',
    'Placeholder name' => 'Nombre del marcador de posición',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'El nombre del elemento debe contener al menos dos caracteres sin espacios ni signos especiales excepto \'_\'',
    'The given element name is already in use for this template.' => 'El nombre del elemento dado ya está en uso para esta plantilla.',
    'The given view file path does not exist.' => 'La ruta del archivo de vista proporcionada no existe.',
    'Url shortcut' => 'Atajo de URL',
    'View' => 'Vista',
    'Visibility' => 'Visibilidad',
    'page' => 'página',
    'snippet' => 'snippet',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/es/model.php <==
<?php

return [
    'Abstract' => 'Resumen',
    'Activate PHP based Pages and Snippets' => 'Activar páginas y fragmentos basados ​​en PHP',
    'Attach Files' => 'Adjuntar archivos',
    'Content' => 'Contenido',
    'Empty <br />Container' => 'Contenedor <br> vacío',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Si está deshabilitado, las páginas php existentes seguirán estando en línea, pero no se pueden crear.',
    'Label' => 'Etiqueta',
    'Open in new window' => 'Abrir en una nueva ventana',
    'PHP view path for custom space pages' => 'Ruta de vista PHP para páginas de espacio personalizadas',
    'PHP view path for custom space snippets' => 'Ruta de vista PHP para fragmentos de espacio personalizados',
    'PHP view path for global custom pages' => 'Ruta de vista PHP para páginas personalizadas globales',
    'PHP view path for global custom snippets' => 'Ruta de vista PHP para fragmentos personalizados globales',
    'Placeholder name' => 'Nombre del marcador de posición',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'El nombre del elemento debe contener al menos dos caracteres sin espacios ni signos especiales excepto \'_\'',
    'The given element name is already in use for this template.' => 'El nombre del elemento dado ya está en uso para esta plantilla.',
    'The given view file path does not exist.' => 'La ruta del archivo de vista proporcionada no existe.',
    'Url shortcut' => 'Atajo de URL',
    'View' => 'Vista',
    'Visibility' => 'Visibilidad',
    'page' => 'página',
    'snippet' => 'snippet',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
